abacusai.database_column_feature_mapping — AbacusAI documentation

# abacusai.database_column_feature_mapping

## Classes

`AbstractApiClass` |
`DatabaseColumnFeatureMapping` | Mapping for export of feature group version to database column

## Module Contents

class abacusai.database_column_feature_mapping.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.database_column_feature_mapping.DatabaseColumnFeatureMapping(client, databaseColumn=None, feature=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Mapping for export of feature group version to database column

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - databaseColumn (str) – database column name

    - feature (str) – feature group column it has been matched to

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict